georgia
=======

Various socio-economic variables for counties within the state of Georgia (1990)
-------------------------------------------------------------------------------

* G_utm.shp: attribute and geometry data. (n=159, k=17)

For testing against GWR4 GUI software
-------------------------------------

* georgia_BS_NN_listwise.csv: bisquare nearest neighbor kernel model output
* georgia_BS_NN_summary.txt: bisquare nearest neighbor kernel model summary
* georgia_BS_NN.ctl: bisquare nearest neighbor kernel control file

* georgia_GS_NN_listwise.csv: Gaussian nearest neighbor kernel model output
* georgia_GS_NN_summary.txt: Gaussian nearest neighbor kernel model summary
* georgia_GS_NN.ctl: Gaussian nearest neighbor kernel control file

* georgia_BS_F_listwise.csv: bisquare fixed kernel model output
* georgia_BS_F_summary.txt: bisquare fixed kernel model summary
* georgia_BS_F.ctl: bisquare fixed kernel control file

* georgia_GS_F_listwise.csv: Gaussian fixed kernel model output
* georgia_GS_F_summary.txt: Gaussian fixed kernel model summary
* georgia_GS_F.ctl: Gaussian fixed kernel control file

Data used in:

Fotheringham, A. Stewart, Chris Brunsdon, and Martin Charlton. 2002. Geographically Weighted Regression: The Analysis of Spatially Varying Relationships. John Wiley & Sons.

Oshan, Taylor, Ziqi Li, Wei Kang, Levi J. Wolf, and Alexander S. Fotheringham. 2018. “Mgwr: A Python Implementation of Multiscale Geographically Weighted Regression for Investigating Process Spatial Heterogeneity and Scale.” OSF Preprints. October 2. doi:10.31219/osf.io/bphw9.
